@@ -1,19 +1,7 @@
-/***************************************************************************
-                          kwordquizprefs.cpp  -  description
-                             -------------------
-    begin                : Sun Aug 18 2002
-    copyright            : (C) 2002-2008 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2008 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwordquizprefs.h"
 
@@ -62,7 +50,7 @@ bool KWordQuizPrefs::isDefault()
 void KWordQuizPrefs::updateSettings( )
 {
   m_prefCharacter->updateSettings();
-  emit settingsChanged(QLatin1String(""));
+  Q_EMIT settingsChanged(QLatin1String(""));
 }
 
 void KWordQuizPrefs::updateWidgetsDefault()
