@@ -5,9 +5,14 @@
 
 #include "kwqquizmodel.h"
 
+#include "blankanswer.h"
+#include "krandomsequence.h"
 #include "kwqsortfiltermodel.h"
 #include "kwqtablemodel.h"
-#include "krandomsequence.h"
+
+#include <QRandomGenerator>
+
+#include <KRandom>
 
 KWQQuizModel::KWQQuizModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
@@ -123,8 +128,7 @@ void KWQQuizModel::activateBaseList()
         m_list.append(l);
 
     if (m_quizMode > 2) {
-        KRandomSequence rs;
-        rs.randomize(m_list);
+        KRandom::shuffle(m_list, QRandomGenerator::global());
     };
 
     m_questionCount = m_list.count();
@@ -147,20 +151,12 @@ bool KWQQuizModel::checkAnswer(const QString & a)
         if (!m_correctBlank.isEmpty()) {
             QStringList la, ls;
             if (ans.indexOf(';') > 0)
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                ls = ans.split(';', QString::SkipEmptyParts);
-#else
                 ls = ans.split(';', Qt::SkipEmptyParts);
-#endif
             else
                 ls.append(ans);
 
             if (m_correctBlank.indexOf(';') > 0)
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                la = m_correctBlank.split(';', QString::SkipEmptyParts);
-#else
                 la = m_correctBlank.split(';', Qt::SkipEmptyParts);
-#endif
             else
                 la.append(m_correctBlank);
 
@@ -210,16 +206,15 @@ bool KWQQuizModel::checkAnswer(const QString & a)
 QStringList KWQQuizModel::multiOptions()
 {
   QStringList ls;
-  KRandomSequence rs;
   int a = -1;
   int b = -1;
 
   do
-    a = rs.getLong(m_questionCount);
+    a = QRandomGenerator::global()->bounded(m_questionCount);
   while(a == m_currentQuestion);
 
   do
-    b = rs.getLong(m_questionCount);
+    b = QRandomGenerator::global()->bounded(m_questionCount);
   while(b == m_currentQuestion || b == a);
 
   int row =  m_list.at(m_currentQuestion);
@@ -241,7 +236,7 @@ QStringList KWQQuizModel::multiOptions()
       }
   }
 
-  rs.randomize(ls);
+  KRandom::shuffle(ls, QRandomGenerator::global());
 
   return ls;
 }
@@ -263,36 +258,9 @@ QString KWQQuizModel::quizIcon(QuizIcon ico)
     return s;
 }
 
-
-QString KWQQuizModel::yourAnswer(const QString & s)
+QString KWQQuizModel::yourAnswer(const QString &givenAnswer) const
 {
-    QString result = s;
-
-    if (!m_answerBlank.isEmpty()) {
-        result.clear();
-        QStringList ls;
-
-        if (s.indexOf(';') > 0)
-            ls = s.split(';');
-        else
-            ls.append(s);
-
-        result = m_answerBlank.replace(QLatin1String(".........."), QLatin1String("<u></u>"));
-
-        int offset = 0, counter = 0;
-        while (offset >= 0) {
-            offset = result.indexOf(QStringLiteral("<u>"), offset);
-            if (offset >= 0) {
-                result.insert(offset + 3, ls[counter]);
-                offset++;
-                counter++;
-            }
-        }
-        result.append("</qt>");
-        result.prepend("<qt>");
-    }
-
-    return result;
+    return BlankAnswer::yourAnswerResult(givenAnswer, m_answerBlank);
 }
 
 
@@ -329,43 +297,23 @@ QString KWQQuizModel::question()
     return s;
 }
 
-
 QString KWQQuizModel::blankAnswer()
 {
-    QString r = QLatin1String("");
     m_correctBlank.clear();
     m_answerBlank.clear();
-    QString tTemp;
 
     if (m_quizType == Prefs::EnumStartSession::QA && Prefs::enableBlanks()) {
-        int row =  m_list.at(m_currentQuestion);
-        tTemp = data(index(qAbs(row), column(row), QModelIndex()), Qt::DisplayRole).toString();
-        r = tTemp;
-        QRegExp rx;
-        rx.setMinimal(true);
-        rx.setPattern(QStringLiteral("\\[.*\\]"));
+        int row = m_list.at(m_currentQuestion);
+        const QString input = data(index(qAbs(row), column(row), QModelIndex()), Qt::DisplayRole).toString();
 
-        r.replace(rx, QStringLiteral(".........."));
+        const BlankAnswer::BlankResult result = BlankAnswer::blankAnswer(input);
 
-        if (r != tTemp) {
-            m_answerBlank = r;
-            int offset = 0;
-            while (offset >= 0) {
-                offset = rx.indexIn(tTemp, offset);
-                if (offset >= 0) {
-                    if (m_correctBlank.length() > 0)
-                        m_correctBlank = m_correctBlank + "; " + tTemp.mid(offset + 1, tTemp.indexOf(']', offset) - offset - 1);
-                    else
-                        m_correctBlank = tTemp.mid(offset + 1, tTemp.indexOf(']', offset) - offset - 1);
-                offset++;
-                }
-            }
-        }
+        m_answerBlank = result.blankedAnswer;
+        m_correctBlank = result.correctAnswer;
     }
     return m_answerBlank;
 }
 
-
 QString KWQQuizModel::answer()
 {
     int row =  m_list.at(m_currentQuestion);
