@@ -20,12 +20,10 @@
 #include <QPrintPreviewDialog>
 #include <QPrinter>
 #include <QTextCursor>
-#include <QTextLayout>
 #include <QTextTable>
 
 #include <KLocalizedString>
 #include <KNotification>
-#include <KConfigGroup>
 
 #include "kwqtablemodel.h"
 #include "keduvocdocument.h"
@@ -105,7 +103,11 @@ bool KWQTableView::doHtmlExport(const QUrl &url)
     out.setCodec("utf-8");
 #endif
     createPages(&printer, &td, false);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     out << td.toHtml("utf-8");
+#else
+    out << td.toHtml();
+#endif
     data.close();
     success = true;
   }
@@ -118,7 +120,7 @@ void KWQTableView::createPages(QPrinter *printer, QTextDocument *textDoc, bool s
   int myDpi = printer->logicalDpiY();
 
   if (Prefs::printStyle() == Prefs::EnumPrintStyle::Flashcard) {
-    printer->setOrientation(QPrinter::Landscape);
+    printer->setPageOrientation(QPageLayout::Landscape);
 
     int cardWidth = qRound(5 * qreal(myDpi));
     int cardHeight = qRound(3 * qreal(myDpi));
