@@ -10,8 +10,8 @@
 #include <QMenu>
 #include <QPointer>
 #include <QTimer>
+#include <QRandomGenerator>
 
-#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardAction>
@@ -67,7 +67,6 @@ KWQTutor::KWQTutor(const QUrl &fileToOpen, QWidget *parent) : KStatusNotifierIte
   m_timer = new QTimer;
   connect (m_timer, &QTimer::timeout, this, &KWQTutor::updateTimer);
 
-  m_randomSequence = new KRandomSequence();
   m_flashcard = new KWQTutorFlashCard();
 
   m_tutorDoc = new KEduVocDocument();
@@ -85,7 +84,6 @@ KWQTutor::KWQTutor(const QUrl &fileToOpen, QWidget *parent) : KStatusNotifierIte
 
 KWQTutor::~KWQTutor()
 {
-    delete m_randomSequence;
 }
 
 void KWQTutor::updateTimer()
@@ -94,14 +92,12 @@ void KWQTutor::updateTimer()
   if (Prefs::tutorTiming() == Prefs::EnumTutorTiming::FixedInterval)
     interval = Prefs::tutorEvery();
   else if (Prefs::tutorTiming() == Prefs::EnumTutorTiming::RandomInterval) {
-    do
-      interval = m_randomSequence->getLong(Prefs::tutorMax());
-    while (interval < Prefs::tutorMin());
+    interval = QRandomGenerator::global()->bounded(Prefs::tutorMin(), Prefs::tutorMax());
   }
   qDebug() << interval;
   m_timer->start(1000 * 60 * interval);
   if (!m_flashcard->isVisible())
-    showFlashcard(m_randomSequence->getLong(m_tutorDoc->lesson()->entryCount(KEduVocLesson::Recursive) - 1));
+    showFlashcard(QRandomGenerator::global()->bounded(m_tutorDoc->lesson()->entryCount(KEduVocLesson::Recursive) - 1));
 }
 
 void KWQTutor::startStopPressed()
