@@ -17,7 +17,6 @@
 #include "kwordquiz.h"
 #include "kwordquiz_version.h"
 
-static const char *description = I18N_NOOP("A powerful flashcard and vocabulary learning program");
 int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -28,12 +27,11 @@ int main(int argc, char *argv[])
     QApplication::setApplicationName(QStringLiteral("kwordquiz"));
     QApplication::setApplicationVersion(KWORDQUIZ_VERSION_STRING);
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-    QApplication::setApplicationDisplayName(i18n("kwordquiz"));
 
     KAboutData aboutData(QStringLiteral("kwordquiz"),
                          i18n("KWordQuiz"),
                          KWORDQUIZ_VERSION_STRING,
-                         i18n(description),
+                         i18n("A powerful flashcard and vocabulary learning program"),
                          KAboutLicense::GPL_V2,
                          i18n("(c) 2003-2010, Peter Hedlund"),
                          QString(),
@@ -47,6 +45,10 @@ int main(int argc, char *argv[])
 
     KCrash::initialize();
 
+#ifdef Q_OS_WIN
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
